
/*              Copyright 1993 Colorado State University                    */
/*                      All Rights Reserved                                 */

/*****************************************************************************
**
**  FILE:      flow_double.c
**
**  FUNCTION:  void flow_double()
**
**  PURPOSE:   Schedules a double precision flow by storing the arguments in a
**             stack which will be accessed by the function 'flowup_double'
**             which performs the actual flow for all stack elements where
**             'when' is less than or equal to time.
**  
**  INPUTS:
**    from    - memory location to flow amount from
**    to      - memory location to flow amount to
**    when    - when in simulation time the flow occurred
**    howmuch - amount of element to flow from the from location to the to
**              location
**
**  GLOBAL VARIABLES:
**    flowstack_double[].from - memory location to flow amount from
**    flowstack_double[].to   - memory location to flow amount to
**    flowstack_double[].when - when in simulation time the flow occurred
**    flowstack_double[].amt  - amount of element to flow from the from
**                              location to the to location
**    LENFST_DOUBLE           - maximum number of elements in
**                              flowstack_double array
**
**  LOCAL VARIABLES:
**    None
**
**  OUTPUT:
**    flowstack_double[] - variables used in Century flow double precision
**                         routines
**    nflows_double      - indicates number of unflowed events stored in
**                         flowstack
**
**  CALLED BY:
**    pschem()
**
**  CALLS:
**    flow_err() - handles errors generated by the flow functions
**
*****************************************************************************/

#include <stdio.h>
#include <stdlib.h>
#include "flow_double.h"

    void flow_double(double *from, double *to, float *when, double *howmuch)
    {

      /* Increment the number of flows stored in the stack */
      nflows_double += 1;

      if (nflows_double > LENFST_DOUBLE) {
        /* Stack Overflow */
        flow_err(1, *when);
        exit(1);
      } else {
        /* Store the arguments in the stack */
        flowstack_double[nflows_double].from = from;
        flowstack_double[nflows_double].to = to;
        flowstack_double[nflows_double].when = *when;
        flowstack_double[nflows_double].amt = *howmuch;
      }

      return;
    }
