
/*              Copyright 1993 Colorado State University                    */
/*                      All Rights Reserved                                 */

/*****************************************************************************
**
**  FILE:      flow_double_in.c
**
**  FUNCTION:  void flow_double_in()
**
**  PURPOSE:   Schedules a double precision flow by storing the arguments in a
**             stack which will be accessed by the function 'flowup_double_in'
**             which performs the actual flow for all stack elements where
**             'when' is less than or equal to time.
**  
**  INPUTS:
**    from    - memory location to flow amount from
**    to      - memory location to flow amount to
**    when    - when in simulation time the flow occurred
**    howmuch - amount of element to flow from the from location to the to
**              location
**
**  GLOBAL VARIABLES:
**    flowstack_double_in[].from - memory location to flow amount from
**    flowstack_double_in[].to   - memory location to flow amount to
**    flowstack_double_in[].when - when in simulation time the flow occurred
**    flowstack_double_in[].amt  - amount of element to flow from the from
**                                 location to the to location
**    LENFST_DOUBLE_IN           - maximum number of elements in
**                                 flowstack_double_in array
**
**  LOCAL VARIABLES:
**    None
**
**  OUTPUT:
**    flowstack_double_in[] - variables used in Century flow double precision
**                            routines
**    nflows_double_in      - indicates number of unflowed events stored in
**                            flowstack
**
**  CALLED BY:
**    pschem()
**
**  CALLS:
**    flow_err() - handles errors generated by the flow functions
**
*****************************************************************************/

#include <stdio.h>
#include <stdlib.h>
#include "flow_double_in.h"

    void flow_double_in(float *from, double *to, float *when, double *howmuch)
    {

      /* Increment the number of flows stored in the stack */
      nflows_double_in += 1;

      if (nflows_double_in > LENFST_DOUBLE_IN) {
        /* Stack Overflow */
        flow_err(1, *when);
        exit(1);
      } else {
        /* Store the arguments in the stack */
        flowstack_double_in[nflows_double_in].from = from;
        flowstack_double_in[nflows_double_in].to = to;
        flowstack_double_in[nflows_double_in].when = *when;
        flowstack_double_in[nflows_double_in].amt = *howmuch;
      }

      return;
    }
