
/*              Copyright 1993 Colorado State University                    */
/*                      All Rights Reserved                                 */

/*****************************************************************************
**
**  FILE:      flow_double_out.c
**
**  FUNCTION:  void flow_double_out()
**
**  PURPOSE:   Schedules a double precision flow by storing the arguments in a
**             stack which will be accessed by the function 'flowup_double_out'
**             which performs the actual flow for all stack elements where
**             'when' is less than or equal to time.
**  
**  INPUTS:
**    from    - memory location to flow amount from
**    to      - memory location to flow amount to
**    when    - when in simulation time the flow occurred
**    howmuch - amount of element to flow from the from location to the to
**              location
**
**  GLOBAL VARIABLES:
**    flowstack_double_out[].from - memory location to flow amount from
**    flowstack_double_out[].to   - memory location to flow amount to
**    flowstack_double_out[].when - when in simulation time the flow occurred
**    flowstack_double_out[].amt  - amount of element to flow from the from
**                                  location to the to location
**    LENFST_DOUBLE_OUT           - maximum number of elements in
**                                  flowstack_double_out array
**
**  LOCAL VARIABLES:
**    None
**
**  OUTPUT:
**    flowstack_double_out[] - variables used in Century flow double precision
**                             routines
**    nflows_double_out      - indicates number of unflowed events stored in
**                             flowstack
**
**  CALLED BY:
**    pschem()
**
**  CALLS:
**    flow_err() - handles errors generated by the flow functions
**
*****************************************************************************/

#include <stdio.h>
#include <stdlib.h>
#include "flow_double_out.h"

    void flow_double_out(double *from, float *to, float *when, double *howmuch)
    {

      /* Increment the number of flows stored in the stack */
      nflows_double_out += 1;

      if (nflows_double_out > LENFST_DOUBLE_OUT) {
        /* Stack Overflow */
        flow_err(1, *when);
        exit(1);
      } else {
        /* Store the arguments in the stack */
        flowstack_double_out[nflows_double_out].from = from;
        flowstack_double_out[nflows_double_out].to = to;
        flowstack_double_out[nflows_double_out].when = *when;
        flowstack_double_out[nflows_double_out].amt = *howmuch;
      }

      return;
    }
